==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-angular-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-angular-core";
/**
 * @hidden
 */
var CustomIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.zk = null;
        _this.zj = null;
        return _this;
    }
    CustomIndicator.prototype.get_yy = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.get_zb = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.ya = function (a, b) {
        var e_1, _a;
        var c = this.um(a, b);
        var d = this.un(c);
        var e = new List$1(String_$type, 0);
        if (this.basedOnColumns != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.basedOnColumns(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = __values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.zk;
        },
        set: function (a) {
            this.zk = a;
            this.yi();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.zj;
        },
        set: function (a) {
            this.zj = a;
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.x7 = function (a, b) {
        _super.prototype.x7.call(this, a, b);
        if (this.indicator != null) {
            var c = this.um(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.vi(this.ya(a, b))) {
                return false;
            }
            this.indicator(this, new FinancialEventArgs(a, b, c, this.un(c), this));
            if (this.y0(c) && this.uv != null) {
                this.uv.c1();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm5/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-angular-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-angular-core";
/**
 * @hidden
 */
var CustomIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomIndicator, _super);
    function CustomIndicator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.acf = null;
        _this.ace = null;
        return _this;
    }
    CustomIndicator.prototype.bj = function () {
        return new CustomIndicator();
    };
    CustomIndicator.prototype.get_abt = function () {
        return new CustomIndicatorStrategy();
    };
    Object.defineProperty(CustomIndicator.prototype, "abt", {
        get: function () {
            return this.get_abt();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.get_ab6 = function () {
        return CustomIndicator.$;
    };
    Object.defineProperty(CustomIndicator.prototype, "ab6", {
        get: function () {
            return this.get_ab6();
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.aa5 = function (a, b) {
        var e_1, _a;
        var c = this.xh(a, b);
        var d = this.xi(c);
        var e = new List$1(String_$type, 0);
        if (this.basedOnColumns != null) {
            var f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
            this.basedOnColumns(this, f);
            if (f.basedOn != null) {
                try {
                    for (var _b = __values(fromEnum(f.basedOn)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var g = _c.value;
                        e.add(g);
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return))
                            _a.call(_b);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            }
        }
        return e;
    };
    Object.defineProperty(CustomIndicator.prototype, "indicator", {
        get: function () {
            return this.acf;
        },
        set: function (a) {
            this.acf = a;
            this.abd();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CustomIndicator.prototype, "basedOnColumns", {
        get: function () {
            return this.ace;
        },
        set: function (a) {
            this.ace = a;
        },
        enumerable: false,
        configurable: true
    });
    CustomIndicator.prototype.aa2 = function (a, b) {
        _super.prototype.aa2.call(this, a, b);
        if (this.indicator != null) {
            var c = this.xh(a, b);
            if (b == 0) {
                return false;
            }
            if (!this.yd(this.aa5(a, b))) {
                return false;
            }
            this.indicator(this, new FinancialEventArgs(a, b, c, this.xi(c), this));
            if (this.abv(c) && this.xn != null) {
                this.xn.c1();
            }
            return true;
        }
        return false;
    };
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
}(StrategyBasedIndicator));
export { CustomIndicator };
